@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -710,7 +710,9 @@ class CbsClient(AbstractClient):
 
 
     def GetSnapOverview(self, request):
-        """获取快照概览信息
+        """为进一步规范化API命名，该接口决定预下线，新接口命名为：DescribeSnapshotOverview
+
+        获取快照概览信息
 
         :param request: Request instance for GetSnapOverview.
         :type request: :class:`tencentcloud.cbs.v20170312.models.GetSnapOverviewRequest`
@@ -983,7 +985,6 @@ class CbsClient(AbstractClient):
         """本接口 (ModifyDisksChargeType) 用于切换云硬盘的计费模式。
 
         非弹性云硬盘不支持此接口，请通过修改实例计费模式接口将实例连同非弹性云硬盘一起转换。
-        默认接口请求频率限制：10次/秒。
 
         :param request: Request instance for ModifyDisksChargeType.
         :type request: :class:`tencentcloud.cbs.v20170312.models.ModifyDisksChargeTypeRequest`
