@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 当前用户鉴权失败。
+AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
@@ -26,15 +29,9 @@ FAILEDOPERATION_APISERVERFAIL = 'FailedOperation.APIServerFail'
 # 客户端已离线。
 FAILEDOPERATION_AGENTOFFLINE = 'FailedOperation.AgentOffline'
 
-# 关闭专业版失败。
-FAILEDOPERATION_CLOSEPROVERSION = 'FailedOperation.CloseProVersion'
-
 # 导出文件失败。
 FAILEDOPERATION_EXPORT = 'FailedOperation.Export'
 
-# 询价失败。
-FAILEDOPERATION_INQUIRYPRICE = 'FailedOperation.InquiryPrice'
-
 # 可用license数量不足，缺少1个license，请购买新license。
 FAILEDOPERATION_LICENSEEXCEEDED = 'FailedOperation.LicenseExceeded'
 
@@ -44,15 +41,9 @@ FAILEDOPERATION_MACHINEDELETE = 'FailedOperation.MachineDelete'
 # 无专业版主机。
 FAILEDOPERATION_NOPROFESSIONHOST = 'FailedOperation.NoProfessionHost'
 
-# 开通专业版失败。
-FAILEDOPERATION_OPENPROVERSION = 'FailedOperation.OpenProVersion'
-
 # 多台主机隔离，部分或全部失败。
 FAILEDOPERATION_PARTSEPARATE = 'FailedOperation.PartSeparate'
 
-# 不能关闭预付费模式专业版。
-FAILEDOPERATION_PREPAYMODE = 'FailedOperation.PrePayMode'
-
 # 开启防护失败。
 FAILEDOPERATION_PROTECTSTARTFAIL = 'FailedOperation.ProtectStartFail'
 
@@ -62,18 +53,12 @@ FAILEDOPERATION_RECOVER = 'FailedOperation.Recover'
 # 重新检测漏洞失败。
 FAILEDOPERATION_RESCANVUL = 'FailedOperation.RescanVul'
 
-# 该主机已有重新检测任务正在执行中。
-FAILEDOPERATION_RESCANVULPROCESSINUSE = 'FailedOperation.RescanVulProcessInUse'
-
 # 单台主机隔离失败。
 FAILEDOPERATION_SINGLESEPARATE = 'FailedOperation.SingleSeparate'
 
 # 创建基线策略超过上限。
 FAILEDOPERATION_TOOMANYSTRATEGY = 'FailedOperation.TooManyStrategy'
 
-# 交易失败。
-FAILEDOPERATION_TRADEERROR = 'FailedOperation.TradeError'
-
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -104,12 +89,18 @@ INVALIDPARAMETER_NAMEHASREPETITION = 'InvalidParameter.NameHasRepetition'
 # 参数解析错误。
 INVALIDPARAMETER_PARSINGERROR = 'InvalidParameter.ParsingError'
 
+# 端口格式不合法。
+INVALIDPARAMETER_PORTNOVALID = 'InvalidParameter.PortNoValid'
+
 # 正则参数格式错误。
 INVALIDPARAMETER_REGEXRULEERROR = 'InvalidParameter.RegexRuleError'
 
 # 进程名/目标IP/目标端口，不能同时为空。
 INVALIDPARAMETER_REVERSHELLKEYFIELDALLEMPTY = 'InvalidParameter.ReverShellKeyFieldAllEmpty'
 
+# 规则类接口，主机重复。
+INVALIDPARAMETER_RULEHOSTDUPLICATEERR = 'InvalidParameter.RuleHostDuplicateErr'
+
 # 规则类接口，主机IP不正确。
 INVALIDPARAMETER_RULEHOSTIPERR = 'InvalidParameter.RuleHostipErr'
 
@@ -131,11 +122,26 @@ MISSINGPARAMETER = 'MissingParameter'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 资源被占用。
+RESOURCEINUSE = 'ResourceInUse'
+
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# 扫描机器不存在。
+RESOURCENOTFOUND_MACHINENOTFOUND = 'ResourceNotFound.MachineNotFound'
+
+# 资源不可用。
+RESOURCEUNAVAILABLE = 'ResourceUnavailable'
+
+# 未授权操作。
+UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
+
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
