@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -166,6 +166,8 @@ class DomainClient(AbstractClient):
 
     def CreateCustomDnsHost(self, request):
         """创建自定义DNS Host
+        域名在“正常状态”下可创建，域名如果“未实名”则无法创建，账户如果未实名则无法创建。
+        默认每个域名 自定义DNS Host 数量不超过10个
 
         :param request: Request instance for CreateCustomDnsHost.
         :type request: :class:`tencentcloud.domain.v20180808.models.CreateCustomDnsHostRequest`
@@ -304,6 +306,7 @@ class DomainClient(AbstractClient):
 
     def DeleteCustomDnsHost(self, request):
         """删除自定义DNS Host
+        仅能删除域名在“正常状态”下，已经创建过的自定义Host，域名如果“未实名”或账户未实名，则无法操作
 
         :param request: Request instance for DeleteCustomDnsHost.
         :type request: :class:`tencentcloud.domain.v20180808.models.DeleteCustomDnsHostRequest`
@@ -972,6 +975,7 @@ class DomainClient(AbstractClient):
 
     def ModifyCustomDnsHost(self, request):
         """修改自定义DNS Host
+        域名在“正常状态”下可修改已经存在的自定义DNS Host，域名如果“未实名”则无法修改，账户如果未实名则无法修改。 默认每个域名 自定义DNS Host 数量不超过10个
 
         :param request: Request instance for ModifyCustomDnsHost.
         :type request: :class:`tencentcloud.domain.v20180808.models.ModifyCustomDnsHostRequest`
@@ -1063,7 +1067,7 @@ class DomainClient(AbstractClient):
 
 
     def ModifyTemplate(self, request):
-        """修改模板信息
+        """修改模板信息,仅能修改模板未通过审核的，即[模板详情](https://cloud.tencent.com/document/product/242/50018)中：AuditStatus不为Approved状态的
 
         :param request: Request instance for ModifyTemplate.
         :type request: :class:`tencentcloud.domain.v20180808.models.ModifyTemplateRequest`
