@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,6 +38,9 @@ class Aspect(AbstractModel):
 
     @property
     def Name(self):
+        """维度名字
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -46,6 +49,9 @@ class Aspect(AbstractModel):
 
     @property
     def Score(self):
+        """维度得分
+        :rtype: float
+        """
         return self._Score
 
     @Score.setter
@@ -54,6 +60,9 @@ class Aspect(AbstractModel):
 
     @property
     def Percentage(self):
+        """维度分数占比
+        :rtype: float
+        """
         return self._Percentage
 
     @Percentage.setter
@@ -75,6 +84,95 @@ class Aspect(AbstractModel):
         
 
 
+class CompositionContext(AbstractModel):
+    """图像识别批改接口返回的作文文本信息或批改信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Content: 作文内容
+        :type Content: str
+        :param _CorrectData: 批改结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CorrectData: :class:`tencentcloud.ecc.v20181213.models.CorrectData`
+        :param _TaskId: 任务 id，用于查询接口
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TaskId: str
+        :param _SessionId: 图像识别唯一标识，一次识别一个 SessionId
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SessionId: str
+        """
+        self._Content = None
+        self._CorrectData = None
+        self._TaskId = None
+        self._SessionId = None
+
+    @property
+    def Content(self):
+        """作文内容
+        :rtype: str
+        """
+        return self._Content
+
+    @Content.setter
+    def Content(self, Content):
+        self._Content = Content
+
+    @property
+    def CorrectData(self):
+        """批改结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.CorrectData`
+        """
+        return self._CorrectData
+
+    @CorrectData.setter
+    def CorrectData(self, CorrectData):
+        self._CorrectData = CorrectData
+
+    @property
+    def TaskId(self):
+        """任务 id，用于查询接口
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
+        return self._TaskId
+
+    @TaskId.setter
+    def TaskId(self, TaskId):
+        self._TaskId = TaskId
+
+    @property
+    def SessionId(self):
+        """图像识别唯一标识，一次识别一个 SessionId
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
+        return self._SessionId
+
+    @SessionId.setter
+    def SessionId(self, SessionId):
+        self._SessionId = SessionId
+
+
+    def _deserialize(self, params):
+        self._Content = params.get("Content")
+        if params.get("CorrectData") is not None:
+            self._CorrectData = CorrectData()
+            self._CorrectData._deserialize(params.get("CorrectData"))
+        self._TaskId = params.get("TaskId")
+        self._SessionId = params.get("SessionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class CompostionContext(AbstractModel):
     """图像识别批改接口返回的作文文本信息或批改信息
 
@@ -101,6 +199,9 @@ class CompostionContext(AbstractModel):
 
     @property
     def Content(self):
+        """作文内容
+        :rtype: str
+        """
         return self._Content
 
     @Content.setter
@@ -109,6 +210,10 @@ class CompostionContext(AbstractModel):
 
     @property
     def CorrectData(self):
+        """批改结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.CorrectData`
+        """
         return self._CorrectData
 
     @CorrectData.setter
@@ -117,6 +222,10 @@ class CompostionContext(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务 id，用于查询接口
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -125,6 +234,10 @@ class CompostionContext(AbstractModel):
 
     @property
     def SessionId(self):
+        """图像识别唯一标识，一次识别一个 SessionId
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._SessionId
 
     @SessionId.setter
@@ -172,6 +285,9 @@ class CorrectData(AbstractModel):
 
     @property
     def Score(self):
+        """总得分
+        :rtype: float
+        """
         return self._Score
 
     @Score.setter
@@ -180,6 +296,9 @@ class CorrectData(AbstractModel):
 
     @property
     def ScoreCat(self):
+        """各项得分详情
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.ScoreCategory`
+        """
         return self._ScoreCat
 
     @ScoreCat.setter
@@ -188,6 +307,9 @@ class CorrectData(AbstractModel):
 
     @property
     def Comment(self):
+        """综合评价
+        :rtype: str
+        """
         return self._Comment
 
     @Comment.setter
@@ -196,6 +318,9 @@ class CorrectData(AbstractModel):
 
     @property
     def SentenceComments(self):
+        """句子点评
+        :rtype: list of SentenceCom
+        """
         return self._SentenceComments
 
     @SentenceComments.setter
@@ -269,6 +394,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def Image(self):
+        """图片的url链接或base64数据。每张图片数据作为数组的一个元素，数组个数与图片个数保持一致。存放类别依据InputType而定，url与base64编码不能混合使用。
+        :rtype: list of str
+        """
         return self._Image
 
     @Image.setter
@@ -277,6 +405,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def InputType(self):
+        """输出图片类型，0 表示 Image 字段是图片所在的 url，1 表示 Image 字段是 base64 编码后的图像数据。
+        :rtype: int
+        """
         return self._InputType
 
     @InputType.setter
@@ -285,6 +416,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def EccAppid(self):
+        """业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数。
+        :rtype: str
+        """
         return self._EccAppid
 
     @EccAppid.setter
@@ -293,6 +427,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def SessionId(self):
+        """图像识别唯一标识，一次识别一个 SessionId，使用识别功能时 SessionId 可用于使用文本批改接口，此时按图像批改价格收费；如使用文本批改接口时没有传入 SessionId，则需要收取文本批改的费用。
+        :rtype: str
+        """
         return self._SessionId
 
     @SessionId.setter
@@ -301,6 +438,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def ServerType(self):
+        """服务类型，0：“多图像识别”，只返回识别结果；1：“多图像批改”，同时返回识别结果与批改结果。默认为 0。
+        :rtype: int
+        """
         return self._ServerType
 
     @ServerType.setter
@@ -309,6 +449,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def Title(self):
+        """作文题目，可选参数
+        :rtype: str
+        """
         return self._Title
 
     @Title.setter
@@ -317,6 +460,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def Grade(self):
+        """年级标准， 默认以 cet4 为标准，取值与意义如下：elementary 小学，grade7 grade8 grade9分别对应初一，初二，初三。 grade10 grade11 grade12 分别对应高一，高二，高三，以及 cet4 和 cet6 分别表示 英语4级和6级。
+        :rtype: str
+        """
         return self._Grade
 
     @Grade.setter
@@ -325,6 +471,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def Requirement(self):
+        """作文提纲，可选参数，作文的写作要求。
+        :rtype: str
+        """
         return self._Requirement
 
     @Requirement.setter
@@ -333,6 +482,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def ModelTitle(self):
+        """范文标题，可选参数，本接口可以依据提供的范文对作文进行评分。
+        :rtype: str
+        """
         return self._ModelTitle
 
     @ModelTitle.setter
@@ -341,6 +493,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def ModelContent(self):
+        """范文内容，可选参数，同上，范文的正文部分。
+        :rtype: str
+        """
         return self._ModelContent
 
     @ModelContent.setter
@@ -349,6 +504,9 @@ class CorrectMultiImageRequest(AbstractModel):
 
     @property
     def IsAsync(self):
+        """异步模式标识，0：同步模式，1：异步模式。默认为同步模式
+        :rtype: int
+        """
         return self._IsAsync
 
     @IsAsync.setter
@@ -387,22 +545,46 @@ class CorrectMultiImageResponse(AbstractModel):
         r"""
         :param _Data: 接口返回数据
         :type Data: :class:`tencentcloud.ecc.v20181213.models.CompostionContext`
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _ResultData: 接口返回数据
+        :type ResultData: :class:`tencentcloud.ecc.v20181213.models.CompositionContext`
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Data = None
+        self._ResultData = None
         self._RequestId = None
 
     @property
     def Data(self):
+        warnings.warn("parameter `Data` is deprecated", DeprecationWarning) 
+
+        """接口返回数据
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.CompostionContext`
+        """
         return self._Data
 
     @Data.setter
     def Data(self, Data):
+        warnings.warn("parameter `Data` is deprecated", DeprecationWarning) 
+
         self._Data = Data
 
+    @property
+    def ResultData(self):
+        """接口返回数据
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.CompositionContext`
+        """
+        return self._ResultData
+
+    @ResultData.setter
+    def ResultData(self, ResultData):
+        self._ResultData = ResultData
+
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -414,6 +596,9 @@ class CorrectMultiImageResponse(AbstractModel):
         if params.get("Data") is not None:
             self._Data = CompostionContext()
             self._Data._deserialize(params.get("Data"))
+        if params.get("ResultData") is not None:
+            self._ResultData = CompositionContext()
+            self._ResultData._deserialize(params.get("ResultData"))
         self._RequestId = params.get("RequestId")
 
 
@@ -434,6 +619,9 @@ class DescribeTaskRequest(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务 ID
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -442,6 +630,9 @@ class DescribeTaskRequest(AbstractModel):
 
     @property
     def EccAppid(self):
+        """业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数（暂时无需传入）。
+        :rtype: str
+        """
         return self._EccAppid
 
     @EccAppid.setter
@@ -477,7 +668,7 @@ class DescribeTaskResponse(AbstractModel):
         :type CorrectData: :class:`tencentcloud.ecc.v20181213.models.CorrectData`
         :param _Status: 任务状态，“Progressing”: 处理中（此时无结果返回）、“Finished”: 处理完成
         :type Status: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Content = None
@@ -487,6 +678,10 @@ class DescribeTaskResponse(AbstractModel):
 
     @property
     def Content(self):
+        """作文识别文本
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Content
 
     @Content.setter
@@ -495,6 +690,10 @@ class DescribeTaskResponse(AbstractModel):
 
     @property
     def CorrectData(self):
+        """整体的批改结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.CorrectData`
+        """
         return self._CorrectData
 
     @CorrectData.setter
@@ -503,6 +702,9 @@ class DescribeTaskResponse(AbstractModel):
 
     @property
     def Status(self):
+        """任务状态，“Progressing”: 处理中（此时无结果返回）、“Finished”: 处理完成
+        :rtype: str
+        """
         return self._Status
 
     @Status.setter
@@ -511,6 +713,9 @@ class DescribeTaskResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -565,6 +770,9 @@ class ECCRequest(AbstractModel):
 
     @property
     def Content(self):
+        """作文文本，必填
+        :rtype: str
+        """
         return self._Content
 
     @Content.setter
@@ -573,6 +781,9 @@ class ECCRequest(AbstractModel):
 
     @property
     def Title(self):
+        """作文题目，可选参数
+        :rtype: str
+        """
         return self._Title
 
     @Title.setter
@@ -581,6 +792,9 @@ class ECCRequest(AbstractModel):
 
     @property
     def Grade(self):
+        """年级标准， 默认以cet4为标准，取值与意义如下：elementary 小学，grade7 grade8 grade9分别对应初一，初二，初三。 grade10 grade11 grade12 分别对应高一，高二，高三，以及cet4和cet6 分别表示 英语4级和6级。
+        :rtype: str
+        """
         return self._Grade
 
     @Grade.setter
@@ -589,6 +803,9 @@ class ECCRequest(AbstractModel):
 
     @property
     def Requirement(self):
+        """作文提纲，可选参数，作文的写作要求。
+        :rtype: str
+        """
         return self._Requirement
 
     @Requirement.setter
@@ -597,6 +814,9 @@ class ECCRequest(AbstractModel):
 
     @property
     def ModelTitle(self):
+        """范文标题，可选参数，本接口可以依据提供的范文对作文进行评分。
+        :rtype: str
+        """
         return self._ModelTitle
 
     @ModelTitle.setter
@@ -605,6 +825,9 @@ class ECCRequest(AbstractModel):
 
     @property
     def ModelContent(self):
+        """范文内容，可选参数，同上，范文的正文部分。
+        :rtype: str
+        """
         return self._ModelContent
 
     @ModelContent.setter
@@ -613,6 +836,9 @@ class ECCRequest(AbstractModel):
 
     @property
     def EccAppid(self):
+        """业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数（暂时无需传入）。
+        :rtype: str
+        """
         return self._EccAppid
 
     @EccAppid.setter
@@ -621,6 +847,9 @@ class ECCRequest(AbstractModel):
 
     @property
     def IsAsync(self):
+        """异步模式标识，0：同步模式，1：异步模式，默认为同步模式
+        :rtype: int
+        """
         return self._IsAsync
 
     @IsAsync.setter
@@ -629,6 +858,9 @@ class ECCRequest(AbstractModel):
 
     @property
     def SessionId(self):
+        """图像识别唯一标识，一次识别一个 SessionId。当传入此前识别接口使用过的 SessionId，则本次批改按图像批改价格收费；如使用了识别接口且本次没有传入 SessionId，则需要加取文本批改的费用；如果直接使用文本批改接口，则只收取文本批改的费用
+        :rtype: str
+        """
         return self._SessionId
 
     @SessionId.setter
@@ -669,7 +901,7 @@ class ECCResponse(AbstractModel):
         :param _TaskId: 任务 id，用于查询接口
 注意：此字段可能返回 null，表示取不到有效值。
         :type TaskId: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Data = None
@@ -678,6 +910,10 @@ class ECCResponse(AbstractModel):
 
     @property
     def Data(self):
+        """整体的批改结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.CorrectData`
+        """
         return self._Data
 
     @Data.setter
@@ -686,6 +922,10 @@ class ECCResponse(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务 id，用于查询接口
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -694,6 +934,9 @@ class ECCResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -753,6 +996,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def Image(self):
+        """图片所在的url或base64编码后的图像数据，依据InputType而定
+        :rtype: str
+        """
         return self._Image
 
     @Image.setter
@@ -761,6 +1007,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def InputType(self):
+        """输出图片类型，0 表示 Image 字段是图片所在的 url，1 表示 Image 字段是 base64 编码后的图像数据
+        :rtype: int
+        """
         return self._InputType
 
     @InputType.setter
@@ -769,6 +1018,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def EccAppid(self):
+        """业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数（暂时无需传入）。
+        :rtype: str
+        """
         return self._EccAppid
 
     @EccAppid.setter
@@ -777,6 +1029,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def SessionId(self):
+        """图像识别唯一标识，一次识别一个 SessionId，使用识别功能时 SessionId 可用于使用文本批改接口，此时按图像批改价格收费；如使用文本批改接口时没有传入 SessionId，则需要收取文本批改的费用
+        :rtype: str
+        """
         return self._SessionId
 
     @SessionId.setter
@@ -785,6 +1040,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def ServerType(self):
+        """服务类型，0：“图像识别”，只返回识别结果，1：“图像批改”，同时返回识别结果与批改结果。默认为 0
+        :rtype: int
+        """
         return self._ServerType
 
     @ServerType.setter
@@ -793,6 +1051,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def Title(self):
+        """作文题目，可选参数
+        :rtype: str
+        """
         return self._Title
 
     @Title.setter
@@ -801,6 +1062,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def Grade(self):
+        """年级标准， 默认以 cet4 为标准，取值与意义如下：elementary 小学，grade7 grade8 grade9分别对应初一，初二，初三。 grade10 grade11 grade12 分别对应高一，高二，高三，以及 cet4 和 cet6 分别表示 英语4级和6级。
+        :rtype: str
+        """
         return self._Grade
 
     @Grade.setter
@@ -809,6 +1073,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def Requirement(self):
+        """作文提纲，可选参数，作文的写作要求。
+        :rtype: str
+        """
         return self._Requirement
 
     @Requirement.setter
@@ -817,6 +1084,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def ModelTitle(self):
+        """范文标题，可选参数，本接口可以依据提供的范文对作文进行评分。
+        :rtype: str
+        """
         return self._ModelTitle
 
     @ModelTitle.setter
@@ -825,6 +1095,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def ModelContent(self):
+        """范文内容，可选参数，同上，范文的正文部分。
+        :rtype: str
+        """
         return self._ModelContent
 
     @ModelContent.setter
@@ -833,6 +1106,9 @@ class EHOCRRequest(AbstractModel):
 
     @property
     def IsAsync(self):
+        """异步模式标识，0：同步模式，1：异步模式。默认为同步模式
+        :rtype: int
+        """
         return self._IsAsync
 
     @IsAsync.setter
@@ -871,22 +1147,46 @@ class EHOCRResponse(AbstractModel):
         r"""
         :param _Data: 接口返回数据
         :type Data: :class:`tencentcloud.ecc.v20181213.models.CompostionContext`
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _ResultData: 接口返回数据
+        :type ResultData: :class:`tencentcloud.ecc.v20181213.models.CompositionContext`
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Data = None
+        self._ResultData = None
         self._RequestId = None
 
     @property
     def Data(self):
+        warnings.warn("parameter `Data` is deprecated", DeprecationWarning) 
+
+        """接口返回数据
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.CompostionContext`
+        """
         return self._Data
 
     @Data.setter
     def Data(self, Data):
+        warnings.warn("parameter `Data` is deprecated", DeprecationWarning) 
+
         self._Data = Data
 
+    @property
+    def ResultData(self):
+        """接口返回数据
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.CompositionContext`
+        """
+        return self._ResultData
+
+    @ResultData.setter
+    def ResultData(self, ResultData):
+        self._ResultData = ResultData
+
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -898,6 +1198,9 @@ class EHOCRResponse(AbstractModel):
         if params.get("Data") is not None:
             self._Data = CompostionContext()
             self._Data._deserialize(params.get("Data"))
+        if params.get("ResultData") is not None:
+            self._ResultData = CompositionContext()
+            self._ResultData._deserialize(params.get("ResultData"))
         self._RequestId = params.get("RequestId")
 
 
@@ -915,6 +1218,9 @@ class ErrorCoordinate(AbstractModel):
 
     @property
     def Coordinate(self):
+        """维度单词坐标
+        :rtype: list of int
+        """
         return self._Coordinate
 
     @Coordinate.setter
@@ -963,6 +1269,9 @@ class ScoreCategory(AbstractModel):
 
     @property
     def Words(self):
+        """词汇维度
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.Aspect`
+        """
         return self._Words
 
     @Words.setter
@@ -971,6 +1280,9 @@ class ScoreCategory(AbstractModel):
 
     @property
     def Sentences(self):
+        """句子维度
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.Aspect`
+        """
         return self._Sentences
 
     @Sentences.setter
@@ -979,6 +1291,9 @@ class ScoreCategory(AbstractModel):
 
     @property
     def Structure(self):
+        """篇章结构维度
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.Aspect`
+        """
         return self._Structure
 
     @Structure.setter
@@ -987,6 +1302,9 @@ class ScoreCategory(AbstractModel):
 
     @property
     def Content(self):
+        """内容维度
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.Aspect`
+        """
         return self._Content
 
     @Content.setter
@@ -995,6 +1313,9 @@ class ScoreCategory(AbstractModel):
 
     @property
     def Score(self):
+        """维度得分
+        :rtype: float
+        """
         return self._Score
 
     @Score.setter
@@ -1003,6 +1324,9 @@ class ScoreCategory(AbstractModel):
 
     @property
     def Percentage(self):
+        """维度分数占比
+        :rtype: float
+        """
         return self._Percentage
 
     @Percentage.setter
@@ -1052,6 +1376,9 @@ class SentenceCom(AbstractModel):
 
     @property
     def Suggestions(self):
+        """句子错误纠正信息
+        :rtype: list of SentenceSuggest
+        """
         return self._Suggestions
 
     @Suggestions.setter
@@ -1060,6 +1387,9 @@ class SentenceCom(AbstractModel):
 
     @property
     def Sentence(self):
+        """句子信息
+        :rtype: :class:`tencentcloud.ecc.v20181213.models.SentenceItem`
+        """
         return self._Sentence
 
     @Sentence.setter
@@ -1107,6 +1437,9 @@ class SentenceItem(AbstractModel):
 
     @property
     def Sentence(self):
+        """英语句子
+        :rtype: str
+        """
         return self._Sentence
 
     @Sentence.setter
@@ -1115,6 +1448,9 @@ class SentenceItem(AbstractModel):
 
     @property
     def ParaID(self):
+        """段落id
+        :rtype: int
+        """
         return self._ParaID
 
     @ParaID.setter
@@ -1123,6 +1459,9 @@ class SentenceItem(AbstractModel):
 
     @property
     def SentenceID(self):
+        """句子id
+        :rtype: int
+        """
         return self._SentenceID
 
     @SentenceID.setter
@@ -1176,6 +1515,9 @@ class SentenceSuggest(AbstractModel):
 
     @property
     def Type(self):
+        """类型
+        :rtype: str
+        """
         return self._Type
 
     @Type.setter
@@ -1184,6 +1526,9 @@ class SentenceSuggest(AbstractModel):
 
     @property
     def ErrorType(self):
+        """错误类型
+        :rtype: str
+        """
         return self._ErrorType
 
     @ErrorType.setter
@@ -1192,6 +1537,9 @@ class SentenceSuggest(AbstractModel):
 
     @property
     def Origin(self):
+        """原始单词
+        :rtype: str
+        """
         return self._Origin
 
     @Origin.setter
@@ -1200,6 +1548,9 @@ class SentenceSuggest(AbstractModel):
 
     @property
     def Replace(self):
+        """替换成 的单词
+        :rtype: str
+        """
         return self._Replace
 
     @Replace.setter
@@ -1208,6 +1559,9 @@ class SentenceSuggest(AbstractModel):
 
     @property
     def Message(self):
+        """提示信息
+        :rtype: str
+        """
         return self._Message
 
     @Message.setter
@@ -1216,6 +1570,9 @@ class SentenceSuggest(AbstractModel):
 
     @property
     def ErrorPosition(self):
+        """维度单词位置，在句子的第几个到第几个单词之间
+        :rtype: list of int
+        """
         return self._ErrorPosition
 
     @ErrorPosition.setter
@@ -1224,6 +1581,9 @@ class SentenceSuggest(AbstractModel):
 
     @property
     def ErrorCoordinates(self):
+        """维度单词坐标，错误单词在图片中的坐标，只有传图片时正常返回，传文字时返回[ ]
+        :rtype: list of ErrorCoordinate
+        """
         return self._ErrorCoordinates
 
     @ErrorCoordinates.setter
