@@ -185,60 +185,6 @@ class EcdnClient(AbstractClient):
             model = models.DescribeIpStatusResponse()
             model._deserialize(response["Response"])
             return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
-    def DescribePurgeTasks(self, request):
-        """ECDN即将下线，如需要动态加速请使用EdgeOne
-
-        DescribePurgeTasks 用于查询刷新任务提交历史记录及执行进度。
-
-        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/37873"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
-
-        :param request: Request instance for DescribePurgeTasks.
-        :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribePurgeTasksRequest`
-        :rtype: :class:`tencentcloud.ecdn.v20191012.models.DescribePurgeTasksResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribePurgeTasks", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribePurgeTasksResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
-    def PurgeUrlsCache(self, request):
-        """ECDN即将下线，如需要动态加速请使用EdgeOne
-
-        PurgeUrlsCache 用于批量刷新Url，一次提交将返回一个刷新任务id。
-
-        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/37870"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
-
-        :param request: Request instance for PurgeUrlsCache.
-        :type request: :class:`tencentcloud.ecdn.v20191012.models.PurgeUrlsCacheRequest`
-        :rtype: :class:`tencentcloud.ecdn.v20191012.models.PurgeUrlsCacheResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("PurgeUrlsCache", params, headers=headers)
-            response = json.loads(body)
-            model = models.PurgeUrlsCacheResponse()
-            model._deserialize(response["Response"])
-            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
