@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -110,6 +110,9 @@ INVALIDPARAMETERVALUE_CHANNELSEXCEEDSRANGE = 'InvalidParameterValue.ChannelsExce
 # 包含无效的ChannelId
 INVALIDPARAMETERVALUE_CONTAININVALIDCHANNELID = 'InvalidParameterValue.ContainInvalidChannelId'
 
+# 包含无效的设备ID
+INVALIDPARAMETERVALUE_CONTAININVALIDDEVICEID = 'InvalidParameterValue.ContainInvalidDeviceId'
+
 # 周期超出限制（1-7）
 INVALIDPARAMETERVALUE_DATAOUTOFRANGE = 'InvalidParameterValue.DataOutOfRange'
 
@@ -419,6 +422,9 @@ INVALIDPARAMETERVALUE_UNSUPPORTEDSTREAMPROTOCOL = 'InvalidParameterValue.Unsuppo
 # 查询的通道数量不能超过3000个
 LIMITEXCEEDED_CHANNELNUMEXCEEDED = 'LimitExceeded.ChannelNumExceeded'
 
+# 查询的国标设备数量不能超过500个
+LIMITEXCEEDED_GBDEVICENUMEXCEEDED = 'LimitExceeded.GBDeviceNumExceeded'
+
 # 时间片段不存在
 MISSINGPARAMETER_EMPTYTIMESECTION = 'MissingParameter.EmptyTimeSection'
 
