@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -52,7 +52,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateAlias(self, request):
@@ -76,7 +76,30 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateCustomDomain(self, request):
+        """创建自定义域名
+
+        :param request: Request instance for CreateCustomDomain.
+        :type request: :class:`tencentcloud.scf.v20180416.models.CreateCustomDomainRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.CreateCustomDomainResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCustomDomain", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateCustomDomainResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateFunction(self, request):
@@ -99,7 +122,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateNamespace(self, request):
@@ -122,7 +145,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateTrigger(self, request):
@@ -145,7 +168,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteAlias(self, request):
@@ -168,7 +191,30 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteCustomDomain(self, request):
+        """删除自定义域名
+
+        :param request: Request instance for DeleteCustomDomain.
+        :type request: :class:`tencentcloud.scf.v20180416.models.DeleteCustomDomainRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.DeleteCustomDomainResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteCustomDomain", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteCustomDomainResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteFunction(self, request):
@@ -191,7 +237,30 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteFunctionVersion(self, request):
+        """该接口根据传入参数删除函数的指定版本。
+
+        :param request: Request instance for DeleteFunctionVersion.
+        :type request: :class:`tencentcloud.scf.v20180416.models.DeleteFunctionVersionRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.DeleteFunctionVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteFunctionVersion", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteFunctionVersionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteLayerVersion(self, request):
@@ -214,7 +283,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteNamespace(self, request):
@@ -237,7 +306,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteProvisionedConcurrencyConfig(self, request):
@@ -260,7 +329,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteReservedConcurrencyConfig(self, request):
@@ -283,7 +352,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteTrigger(self, request):
@@ -306,7 +375,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetAccount(self, request):
@@ -329,7 +398,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetAlias(self, request):
@@ -352,7 +421,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetAsyncEventStatus(self, request):
@@ -375,7 +444,30 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def GetCustomDomain(self, request):
+        """查看云函数自定义域名详情
+
+        :param request: Request instance for GetCustomDomain.
+        :type request: :class:`tencentcloud.scf.v20180416.models.GetCustomDomainRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.GetCustomDomainResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetCustomDomain", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetCustomDomainResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetFunction(self, request):
@@ -398,7 +490,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetFunctionAddress(self, request):
@@ -421,7 +513,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetFunctionEventInvokeConfig(self, request):
@@ -444,7 +536,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetFunctionLogs(self, request):
@@ -467,7 +559,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetLayerVersion(self, request):
@@ -490,7 +582,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetProvisionedConcurrencyConfig(self, request):
@@ -513,7 +605,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetRequestStatus(self, request):
@@ -536,7 +628,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetReservedConcurrencyConfig(self, request):
@@ -559,7 +651,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def Invoke(self, request):
@@ -582,11 +674,11 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def InvokeFunction(self, request):
-        """SCF同步调用函数接口
+        """SCF同步调用函数接口。
 
         :param request: Request instance for InvokeFunction.
         :type request: :class:`tencentcloud.scf.v20180416.models.InvokeFunctionRequest`
@@ -605,7 +697,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListAliases(self, request):
@@ -628,7 +720,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListAsyncEvents(self, request):
@@ -651,7 +743,30 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ListCustomDomains(self, request):
+        """遍历域名列表信息
+
+        :param request: Request instance for ListCustomDomains.
+        :type request: :class:`tencentcloud.scf.v20180416.models.ListCustomDomainsRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.ListCustomDomainsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListCustomDomains", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListCustomDomainsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListFunctions(self, request):
@@ -674,7 +789,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListLayerVersions(self, request):
@@ -697,7 +812,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListLayers(self, request):
@@ -720,7 +835,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListNamespaces(self, request):
@@ -743,7 +858,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListTriggers(self, request):
@@ -766,7 +881,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListVersionByFunction(self, request):
@@ -789,7 +904,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PublishLayerVersion(self, request):
@@ -812,7 +927,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PublishVersion(self, request):
@@ -835,7 +950,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PutProvisionedConcurrencyConfig(self, request):
@@ -858,7 +973,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PutReservedConcurrencyConfig(self, request):
@@ -881,7 +996,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PutTotalConcurrencyConfig(self, request):
@@ -904,7 +1019,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def TerminateAsyncEvent(self, request):
@@ -927,7 +1042,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateAlias(self, request):
@@ -950,7 +1065,30 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateCustomDomain(self, request):
+        """更新自定义域名相关配置
+
+        :param request: Request instance for UpdateCustomDomain.
+        :type request: :class:`tencentcloud.scf.v20180416.models.UpdateCustomDomainRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.UpdateCustomDomainResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateCustomDomain", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateCustomDomainResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateFunctionCode(self, request):
@@ -973,7 +1111,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateFunctionConfiguration(self, request):
@@ -996,7 +1134,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateFunctionEventInvokeConfig(self, request):
@@ -1019,7 +1157,7 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateNamespace(self, request):
@@ -1042,7 +1180,45 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateTrigger(self, request):
+        """支持触发器配置更新。
+        默认接口请求频率限制：20次/秒
+
+        注意：目前只支持timer触发器和ckafka触发器更新！
+
+        timer触发器和ckafka触发器支持更新字段有：Enable、TriggerDesc、Description、CustomArgument。
+
+        timer触发器TriggerDesc支持5段式和7段式的更新。
+
+        ckafka触发器TriggerDesc支持Retry、MaxMsgNum、TimeOut参数更新，不传值表示原值不变，传值不能为空。
+
+        Enable 触发器开启或关闭，传参为OPEN为开启，CLOSE为关闭。不传值表示原值不变，传值不能为空。
+
+        Description 触发器描述，不传值保持原值不变，传值为空则为空。
+
+        CustomArgument 触发器用户附加信息（注意：只有timer触发器展示），不传值保持原值不变，传值为空则为空。
+
+        :param request: Request instance for UpdateTrigger.
+        :type request: :class:`tencentcloud.scf.v20180416.models.UpdateTriggerRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.UpdateTriggerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateTrigger", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateTriggerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateTriggerStatus(self, request):
@@ -1065,4 +1241,4 @@ class ScfClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
