@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -155,12 +155,21 @@ FAILEDOPERATION_CERTIFICATESTATUSNOTALLOWRESUBMIT = 'FailedOperation.Certificate
 # 证书当前状态不允许进行域名验证。
 FAILEDOPERATION_CERTIFICATESTATUSNOTALLOWVERIFY = 'FailedOperation.CertificateStatusNotAllowVerify'
 
+# 上传证书的托管续费证书不能手动提交订单
+FAILEDOPERATION_CERTIFICATESUBMITHOSTINGCERTERROR = 'FailedOperation.CertificateSubmitHostingCertError'
+
+# 证书操作参数无效，证书ID数量超过100。
+FAILEDOPERATION_CERTIFICATESYNCTASKCERTIFICATEIDCOUNTINVALID = 'FailedOperation.CertificateSyncTaskCertificateIdCountInvalid'
+
 # 证书关联云资源查询任务ID无效
 FAILEDOPERATION_CERTIFICATESYNCTASKIDINVALID = 'FailedOperation.CertificateSyncTaskIdInvalid'
 
 # 无法查到当前证书类型详情。
 FAILEDOPERATION_CERTIFICATETYPEINFONOTFOUND = 'FailedOperation.CertificateTypeInfoNotFound'
 
+# 当前为白名单功能，非白名单用户无法使用该功能，请联系SSL证书特殊处理。
+FAILEDOPERATION_CERTIFICATEWHITEFUNCERROR = 'FailedOperation.CertificateWhiteFuncError'
+
 # 证书确认函文件过大（需小于1.4M）。
 FAILEDOPERATION_CONFIRMLETTERTOOLARGE = 'FailedOperation.ConfirmLetterTooLarge'
 
@@ -182,6 +191,9 @@ FAILEDOPERATION_FILETOOLARGE = 'FailedOperation.FileTooLarge'
 # 文件尺寸太小，请上传清晰图片。
 FAILEDOPERATION_FILETOOSMALL = 'FailedOperation.FileTooSmall'
 
+# 生产CSR失败
+FAILEDOPERATION_GENCSRFAIL = 'FailedOperation.GenCSRFail'
+
 # 公司管理人状态错误。
 FAILEDOPERATION_ILLEGALMANAGERSTATUS = 'FailedOperation.IllegalManagerStatus'
 
@@ -323,7 +335,7 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 邮箱格式有误，请您重新输入
 INVALIDPARAMETERVALUE_CERTIFICATEEMAILPARSEINVALID = 'InvalidParameterValue.CertificateEmailParseInvalid'
 
-# 中间根证书不一致
+# 中间证书不一致
 INVALIDPARAMETERVALUE_INTERMEDIATECERTNOTSAME = 'InvalidParameterValue.IntermediateCertNotSame'
 
 # 单位时间内接口请求频率达到限制。
