@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,6 +29,19 @@ class StsClient(AbstractClient):
     def AssumeRole(self, request):
         """申请扮演角色临时访问凭证。
 
+        1、角色策略组成
+
+        （1）角色信任策略：指定谁可以扮演该角色；
+
+        （2）角色权限策略：指定扮演角色后可以执行哪些操作。
+
+
+        2、角色可扮演条件
+
+        （1）给用户绑定允许调用AssumeRole的策略 ；
+
+        （2）将用户添加为角色信任策略中的主体。
+
         :param request: Request instance for AssumeRole.
         :type request: :class:`tencentcloud.sts.v20180813.models.AssumeRoleRequest`
         :rtype: :class:`tencentcloud.sts.v20180813.models.AssumeRoleResponse`
@@ -155,6 +168,29 @@ class StsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetSessionToken(self, request):
+        """获取MFA临时证书
+
+        :param request: Request instance for GetSessionToken.
+        :type request: :class:`tencentcloud.sts.v20180813.models.GetSessionTokenRequest`
+        :rtype: :class:`tencentcloud.sts.v20180813.models.GetSessionTokenResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetSessionToken", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetSessionTokenResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def QueryApiKey(self, request):
         """拉取API密钥列表
 
