@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -83,6 +83,9 @@ INVALIDPARAMETERVALUE_LOGSETNOTFOUND = 'InvalidParameterValue.LogSetNotFound'
 # MPI分布式任务参数ti_mpi_num_of_processes_per_host不能超过GPU卡数。
 INVALIDPARAMETERVALUE_MPIPROCESSESPERHOSTTOOMUCH = 'InvalidParameterValue.MpiProcessesPerHostTooMuch'
 
+# 存储库地址无效。
+INVALIDPARAMETERVALUE_REPOSITORYURLINVALID = 'InvalidParameterValue.RepositoryUrlInvalid'
+
 # 子网不存在。
 INVALIDPARAMETERVALUE_SUBNETNOTFOUND = 'InvalidParameterValue.SubnetNotFound'
 
